fn lock_optional_runtime(
control: &IndexWorkControl,
) -> Result<MutexGuard<'static, OptionalParserRuntime>, CliError>Expand description
Acquire the one process-global owner without hiding cancellation behind a blocking lock.
fn lock_optional_runtime(
control: &IndexWorkControl,
) -> Result<MutexGuard<'static, OptionalParserRuntime>, CliError>Acquire the one process-global owner without hiding cancellation behind a blocking lock.