fn optional_parse_deadline(
control: &IndexWorkControl,
) -> Result<Instant, CliError>Expand description
Bound one worker request by both the operation deadline and the proven file ceiling.
fn optional_parse_deadline(
control: &IndexWorkControl,
) -> Result<Instant, CliError>Bound one worker request by both the operation deadline and the proven file ceiling.