fn retain_runtime_after_parser_failure<T>(
state: &mut OptionalParserRuntimeState<T>,
error: &ParserSupervisorError,
)Expand description
Quarantine one concrete execution owner only when the supervisor reports uncertain cleanup.
fn retain_runtime_after_parser_failure<T>(
state: &mut OptionalParserRuntimeState<T>,
error: &ParserSupervisorError,
)Quarantine one concrete execution owner only when the supervisor reports uncertain cleanup.