fn service_pending_deactivation(
runtime: &mut OptionalParserRuntime,
) -> Result<(), CliError>Expand description
Apply one pending cleanup transition while the caller owns the process-global state.
fn service_pending_deactivation(
runtime: &mut OptionalParserRuntime,
) -> Result<(), CliError>Apply one pending cleanup transition while the caller owns the process-global state.