fn supervisor_error(error: ParserSupervisorError) -> CliErrorExpand description
Preserve task cancellation and deadline state across the supervisor boundary.
fn supervisor_error(error: ParserSupervisorError) -> CliErrorPreserve task cancellation and deadline state across the supervisor boundary.