fn terminal_parse_outcome(outcome: &SymbolParseOutcome) -> boolExpand description
Return whether later jobs must not start after this outcome.
fn terminal_parse_outcome(outcome: &SymbolParseOutcome) -> boolReturn whether later jobs must not start after this outcome.